summaryrefslogtreecommitdiffstats
path: root/Core/Authentication/Token/TokenInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Core/Authentication/Token/TokenInterface.php')
-rw-r--r--Core/Authentication/Token/TokenInterface.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/Core/Authentication/Token/TokenInterface.php b/Core/Authentication/Token/TokenInterface.php
index dec31d5..11f69da 100644
--- a/Core/Authentication/Token/TokenInterface.php
+++ b/Core/Authentication/Token/TokenInterface.php
@@ -11,6 +11,8 @@
namespace Symfony\Component\Security\Core\Authentication\Token;
+use Symfony\Component\Security\Core\Role\RoleInterface;
+
/**
* TokenInterface is the interface for the user authentication information.
*
@@ -31,7 +33,7 @@ interface TokenInterface extends \Serializable
/**
* Returns the user roles.
*
* @return Role[] An array of Role instances.
*/
public function getRoles();
@@ -31,7 +33,7 @@ interface TokenInterface extends \Serializable
* Returns the user roles.
*
- * @return Role[] An array of Role instances.
+ * @return RoleInterface[] An array of RoleInterface instances.
*/
public function getRoles();